#!/bin/sh

function help {
    CODE=0
    if [ $# -gt 0 ]; then
	case $LANG in
	    pt_BR*)	echo "Opcao $1 desconhecida"	;;
	    *)		echo "Unknown option $1"	;;
	esac
	CODE=1
    fi
    case $LANG in
	pt_BR*)
	    echo "-d|--dry-run	Apenas testa componentes"
	    echo "-h|--help	Esta mensagem"
	    echo "-q|--quiet	Nao abre documentacao"
	    ;;
	*)
	    echo "-d|-dry-run	Only test components"
	    echo "-h|-help	This message"
	    echo "-q|--quiet	Do not open documentation"
	    ;;
    esac
    exit $CODE
}

DRYRUN=0
QUIET=0
while [ $# -gt 0 ]; do
    case $1 in
	-d|--dry-run)	DRYRUN=1	;;
	-h|--help)	help		;;
	-q|--quiet)	QUIET=1		;;
	*)		help $1		;;
    esac
    shift
done

function error {
    case $LANG in
	pt_BR*)	echo "Erro inicializando servidor $1" ;;
	    *)	echo "Error starting $1 server" ;;
    esac
    exit 1
}

function start {
    service $1 status
    if [ $? != 0 ]; then
	[ $DRYRUN -ne 0 ] && error $1
	chkconfig --add $1
	service $1 start
	service $1 status || error $1
    fi
}

start postgresql
start httpd
start tomcat6

if [ $DRYRUN -eq 0 ]; then
    createdb -U postgres amadeus_web &&
	psql -U postgres amadeus_web -f /usr/share/amadeus/scripts/amadeuslms_web-v00.95.00.sql
    createdb -U postgres amadeus_mobile &&
	psql -U postgres amadeus_mobile -f /usr/share/amadeus/scripts/amadeuslms_mobile-v00.95.00.sql
    [ -e /usr/share/tomcat6/webapps/amadeuslms.war ] ||
	cp -f /usr/share/amadeus/app/amadeuslms.war /usr/share/tomcat6/webapps

    case $LANG in
	pt_BR*)
	    echo "Acesse http://localhost:8080/amadeuslms"
	    echo "Administrador: Usuario: admin Senha: admin"
	    echo "Interface mobile http://localhost:8080/amadeuslms/mobile.html"
	    ;;
	*)
	    echo "Visit http://localhost:8080/amadeuslms"
	    echo "Administrator: User: admin Password: admin"
	    echo "Mobile interface http://localhost:8080/amadeuslms/mobile.html"
	    ;;
    esac
fi

if [ $QUIET -eq 0 ]; then
    xdg-open /usr/share/amadeus/docs/guia_de_instalacao_linux_amadeus_v00.95.00.pdf
fi
